@@ -3,23 +3,17 @@
 import functools
 import gevent
 from gevent.server import StreamServer
+import kola
 from kola.utils import safe_call
-from kola.callbacks_mixin import AppCallBacksMixin
 from .connection import Connection
 from .stream import GStream
 
 
-class Kola(AppCallBacksMixin):
-    debug = False
-    conn_class = None
-    blueprints = None
-    got_first_request = False
+class Kola(kola.Kola):
 
-    def __init__(self, conn_class=None, **kwargs):
-        super(Kola, self).__init__()
-
-        self.conn_class = conn_class or Connection
-        self.blueprints = dict()
+    def __init__(self, conn_class=None):
+        super(Kola, self).__init__(conn_class or Connection)
+        self.repeat_timer_func_list = []
 
     def handle_stream(self, sock, address):
         self.conn_class(self, GStream(sock), address).process()
