@@ -43,7 +43,7 @@ class GStream(object):
         """
         self.on_close_callback = callback
 
-    def read_util(self, terminator, on_read_complete):
+    def read_until(self, terminator, on_read_complete):
         """
         为了兼容调用的方法
         """
@@ -58,6 +58,9 @@ class GStream(object):
         接收消息
         """
 
+        if not self.rfile:
+            return
+
         # 异常也认为服务器断掉链接了，或者该断掉链接
         data = safe_call(self.rfile.readline)
 
@@ -76,9 +79,11 @@ class GStream(object):
         写数据
         """
 
-        if self.wfile:
-            safe_call(self.wfile.write, data)
-            safe_call(callback)
+        if not self.wfile:
+            return
+
+        safe_call(self.wfile.write, data)
+        safe_call(callback)
 
     def closed(self):
         return not self.sock
