@@ -8,11 +8,11 @@ from kola.utils import safe_call
 class TimeoutMgr(object):
 
     timeout = None
-    deadline = None
 
     def set(self, interval, callback, repeat=False, force=True):
         """
         添加timeout
+        因为如果调用这个spawn的greenlet在interval之前就消失的话，那么cb里的很多操作会失效。比如conn.close
         """
         if self.timeout:
             if force:
@@ -22,11 +22,9 @@ class TimeoutMgr(object):
                 # 已经存在的话，就返回了
                 return
 
-        deadline = time.time() + interval
-
         def callback_wrapper():
             # 这样可以让timeout及时变成None
-            if self.timeout and deadline == self.deadline:
+            if self.timeout == timeout:
                 # 必须要确定，这次调用就是这个timeout引起的
                 self.timeout = None
                 result = safe_call(callback)
@@ -35,8 +33,7 @@ class TimeoutMgr(object):
                     self.set(interval, callback, repeat=repeat)
                 return result
 
-        self.deadline = deadline
-        self.timeout = gevent.spawn_later(interval, callback_wrapper)
+        self.timeout = timeout = gevent.spawn_later(interval, callback_wrapper)
 
     def clear(self):
         """
@@ -48,4 +45,3 @@ class TimeoutMgr(object):
         # 不阻塞
         self.timeout.kill(block=False)
         self.timeout = None
-        self.deadline = None
